@@ -18,35 +18,6 @@ class MocketSocketCore(io.BytesIO):
             os.write(Mocket.w_fd, content)
 
 
-def wrap_ssl_socket(
-    cls,
-    sock,
-    context,
-    keyfile=None,
-    certfile=None,
-    server_side=False,
-    cert_reqs=ssl.CERT_NONE,
-    ssl_version=SSL_PROTOCOL,
-    ca_certs=None,
-    do_handshake_on_connect=True,
-    suppress_ragged_eofs=True,
-    ciphers=None,
-):
-    return cls(
-        sock=sock,
-        keyfile=keyfile,
-        certfile=certfile,
-        server_side=server_side,
-        cert_reqs=cert_reqs,
-        ssl_version=ssl_version,
-        ca_certs=ca_certs,
-        do_handshake_on_connect=do_handshake_on_connect,
-        suppress_ragged_eofs=suppress_ragged_eofs,
-        ciphers=ciphers,
-        _context=context,
-    )
-
-
 def hexdump(binary_string):
     r"""
     >>> hexdump(b"bar foobar foo") == decode_from_bytes(encode_to_bytes("62 61 72 20 66 6F 6F 62 61 72 20 66 6F 6F"))
@@ -63,3 +34,12 @@ def hexload(string):
     """
     string_no_spaces = "".join(string.split())
     return encode_to_bytes(binascii.unhexlify(string_no_spaces))
+
+
+def get_mocketize(wrapper_):
+    import decorator
+
+    if decorator.__version__ < "5":
+        return decorator.decorator(wrapper_)
+    else:
+        return decorator.decorator(wrapper_, kwsyntax=True)
